summaryrefslogtreecommitdiffstats
path: root/src/home/homework-mount.c
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2021-10-22 15:51:00 +0200
committerLennart Poettering <lennart@poettering.net>2021-10-27 22:37:56 +0200
commit2b9855f9d2262f8cc083bf3a372539319a3dd3bd (patch)
treecd078a93233a56c09504703cd38c93aa76d68cd8 /src/home/homework-mount.c
parenthomectl: validate CIFS service name before accepting it (diff)
downloadsystemd-2b9855f9d2262f8cc083bf3a372539319a3dd3bd.tar.xz
systemd-2b9855f9d2262f8cc083bf3a372539319a3dd3bd.zip
homework: make home_move_mount() a bit more generic by renaming first parameter
No actual code change, let's just rename the first parameter, to make it more generically useful in case the first argument is an arbitrary path, not necessarily a username/realm.
Diffstat (limited to 'src/home/homework-mount.c')
-rw-r--r--src/home/homework-mount.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/home/homework-mount.c b/src/home/homework-mount.c
index 7ab503fb7a..5758e85839 100644
--- a/src/home/homework-mount.c
+++ b/src/home/homework-mount.c
@@ -87,17 +87,17 @@ int home_unshare_and_mount(const char *node, const char *fstype, bool discard, u
return home_mount_node(node, fstype, discard, flags);
}
-int home_move_mount(const char *user_name_and_realm, const char *target) {
+int home_move_mount(const char *mount_suffix, const char *target) {
_cleanup_free_ char *subdir = NULL;
const char *d;
int r;
assert(target);
- /* If user_name_and_realm is set, then we'll mount a subdir of the source mount into the host. If
- * it's NULL we'll move the mount itself */
- if (user_name_and_realm) {
- subdir = path_join(HOME_RUNTIME_WORK_DIR, user_name_and_realm);
+ /* If 'mount_suffix' is set, then we'll mount a subdir of the source mount into the host. If it's
+ * NULL we'll move the mount itself */
+ if (mount_suffix) {
+ subdir = path_join(HOME_RUNTIME_WORK_DIR, mount_suffix);
if (!subdir)
return log_oom();